jdk/src/java.naming/share/classes/com/sun/naming/internal/ResourceManager.java
changeset 27565 729f9700483a
parent 25859 3317bb8137f4
child 32029 a5538163e144
--- a/jdk/src/java.naming/share/classes/com/sun/naming/internal/ResourceManager.java	Tue Nov 18 15:25:16 2014 -0800
+++ b/jdk/src/java.naming/share/classes/com/sun/naming/internal/ResourceManager.java	Wed Dec 03 14:22:58 2014 +0000
@@ -60,9 +60,9 @@
     private static final String APP_RESOURCE_FILE_NAME = "jndi.properties";
 
     /*
      * Name of properties file in <java.home>/lib.
      */
-    private static final String JRELIB_PROPERTY_FILE_NAME = "jndi.properties";
+    private static final String JRE_CONF_PROPERTY_FILE_NAME = "jndi.properties";
 
     /*
      * Internal environment property, that when set to "true", disables
@@ -474,7 +474,7 @@
     /*
      * Returns the Hashtable (never null) that results from merging
      * all application resource files available to this thread's
      * context class loader.  The properties file in <java.home>/lib
      * is also merged in.  The results are cached.
      *
      * SECURITY NOTES:
@@ -523,9 +523,9 @@
                     }
                 }
 
                 // Merge in properties from file in <java.home>/lib.
                 InputStream istream =
-                    helper.getJavaHomeLibStream(JRELIB_PROPERTY_FILE_NAME);
+                    helper.getJavaHomeConfStream(JRE_CONF_PROPERTY_FILE_NAME);
                 if (istream != null) {
                     try {
                         Properties props = new Properties();
@@ -60,9 +60,9 @@
 
     /*
-     * Name of properties file in <java.home>/lib.
+     * Name of properties file in <java.home>/conf.
      */
@@ -474,7 +474,7 @@
      * Returns the Hashtable (never null) that results from merging
      * all application resource files available to this thread's
-     * context class loader.  The properties file in <java.home>/lib
+     * context class loader.  The properties file in <java.home>/conf
      * is also merged in.  The results are cached.
      *
@@ -523,9 +523,9 @@
                 }
 
-                // Merge in properties from file in <java.home>/lib.
+                // Merge in properties from file in <java.home>/conf.
                 InputStream istream =